@@ -2,8 +2,7 @@ package chezmoi
 
 import (
 	"encoding/hex"
-
-	"github.com/rs/zerolog"
+	"log/slog"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
@@ -27,7 +26,7 @@ type SourceStateOriginAbsPath AbsPath
 
 // A SourceStateEntry represents the state of an entry in the source state.
 type SourceStateEntry interface {
-	zerolog.LogObjectMarshaler
+	slog.LogValuer
 	Evaluate() error
 	Order() ScriptOrder
 	Origin() SourceStateOrigin
@@ -92,11 +91,12 @@ func (s *SourceStateCommand) Evaluate() error {
 	return nil
 }
 
-// MarshalZerologObject implements
-// github.com/rs/zerolog.LogObjectMarshaler.MarshalZerologObject.
-func (s *SourceStateCommand) MarshalZerologObject(e *zerolog.Event) {
-	e.EmbedObject(chezmoilog.OSExecCmdLogObject{Cmd: s.cmd.Command()})
-	e.Str("origin", s.origin.OriginString())
+// LogValue implements log/slog.LogValuer.LogValue.
+func (s *SourceStateCommand) LogValue() slog.Value {
+	return slog.GroupValue(
+		slog.Any("cmd", chezmoilog.OSExecCmdLogValuer{Cmd: s.cmd.Command()}),
+		slog.String("origin", s.origin.OriginString()),
+	)
 }
 
 // Order returns s's order.
@@ -129,11 +129,12 @@ func (s *SourceStateDir) Evaluate() error {
 	return nil
 }
 
-// MarshalZerologObject implements
-// github.com/rs/zerolog.LogObjectMarshaler.MarshalZerologObject.
-func (s *SourceStateDir) MarshalZerologObject(e *zerolog.Event) {
-	e.Stringer("sourceRelPath", s.sourceRelPath)
-	e.Object("attr", s.Attr)
+// LogValue implements log/slog.LogValuer.LogValue.
+func (s *SourceStateDir) LogValue() slog.Value {
+	return slog.GroupValue(
+		chezmoilog.Stringer("sourceRelPath", s.sourceRelPath),
+		slog.Any("attr", s.Attr),
+	)
 }
 
 // Order returns s's order.
@@ -162,22 +163,23 @@ func (s *SourceStateFile) Evaluate() error {
 	return err
 }
 
-// MarshalZerologObject implements
-// github.com/rs/zerolog.LogObjectMarshaler.MarshalZerologObject.
-func (s *SourceStateFile) MarshalZerologObject(e *zerolog.Event) {
-	e.Stringer("sourceRelPath", s.sourceRelPath)
-	e.Interface("attr", s.Attr)
+// LogValue implements log/slog.LogValuer.LogValue.
+func (s *SourceStateFile) LogValue() slog.Value {
+	attrs := []slog.Attr{
+		chezmoilog.Stringer("sourceRelPath", s.sourceRelPath),
+		slog.Any("attr", s.Attr),
+	}
 	contents, contentsErr := s.Contents()
-	e.Bytes("contents", chezmoilog.FirstFewBytes(contents))
+	attrs = append(attrs, chezmoilog.FirstFewBytes("contents", contents))
 	if contentsErr != nil {
-		e.Str("contentsErr", contentsErr.Error())
+		attrs = append(attrs, slog.Any("contentsErr", contentsErr))
 	}
-	e.Err(contentsErr)
 	contentsSHA256, contentsSHA256Err := s.ContentsSHA256()
-	e.Str("contentsSHA256", hex.EncodeToString(contentsSHA256))
+	attrs = append(attrs, slog.String("contentsSHA256", hex.EncodeToString(contentsSHA256)))
 	if contentsSHA256Err != nil {
-		e.Str("contentsSHA256Err", contentsSHA256Err.Error())
+		attrs = append(attrs, slog.Any("contentsSHA256Err", contentsSHA256Err))
 	}
+	return slog.GroupValue(attrs...)
 }
 
 // Order returns s's order.
@@ -209,9 +211,9 @@ func (s *SourceStateImplicitDir) Evaluate() error {
 	return nil
 }
 
-// MarshalZerologObject implements
-// github.com/rs/zerolog.LogObjectMarshaler.MarshalZerologObject.
-func (s *SourceStateImplicitDir) MarshalZerologObject(e *zerolog.Event) {
+// LogValue implements log/slog.LogValuer.LogValue.
+func (s *SourceStateImplicitDir) LogValue() slog.Value {
+	return slog.GroupValue()
 }
 
 // Order returns s's order.
@@ -239,9 +241,11 @@ func (s *SourceStateRemove) Evaluate() error {
 	return nil
 }
 
-// MarshalZerologObject implements zerolog.LogObjectMarshaler.
-func (s *SourceStateRemove) MarshalZerologObject(e *zerolog.Event) {
-	e.Stringer("targetRelPath", s.targetRelPath)
+// LogValue implements log/slog.LogValuer.LogValue.
+func (s *SourceStateRemove) LogValue() slog.Value {
+	return slog.GroupValue(
+		chezmoilog.Stringer("targetRelPath", s.targetRelPath),
+	)
 }
 
 // Order returns s's order.
