@@ -2,6 +2,8 @@ package cmd
 
 import (
 	"io/fs"
+	"net/http"
+	"net/http/httptest"
 	"path/filepath"
 	"testing"
 
@@ -233,6 +235,27 @@ func TestIssue2132(t *testing.T) {
 	})
 }
 
+func TestIssue2597(t *testing.T) {
+	chezmoitest.WithTestFS(t, map[string]any{
+		"/home/user": map[string]any{
+			".local/share/chezmoi": map[string]any{
+				".chezmoiexternal.toml": chezmoitest.JoinLines(
+					`[".oh-my-zsh"]`,
+					`    type = "archive"`,
+					`    url = "https://github.com/ohmyzsh/ohmyzsh/archive/master.tar.gz"`,
+					`    exact = true`,
+					`    stripComponents = 1`,
+				),
+				".chezmoiignore": chezmoitest.JoinLines(
+					`.oh-my-zsh/cache`,
+				),
+			},
+		},
+	}, func(fileSystem vfs.FS) {
+		assert.NoError(t, newTestConfig(t, fileSystem).execute([]string{"apply"}))
+	})
+}
+
 func TestIssue3206(t *testing.T) {
 	chezmoitest.WithTestFS(t, map[string]any{
 		"/home/user": map[string]any{
@@ -264,3 +287,39 @@ func TestIssue3216(t *testing.T) {
 		assert.NoError(t, newTestConfig(t, fileSystem).execute([]string{"apply"}))
 	})
 }
+
+func TestIssue3703(t *testing.T) {
+	httpServer := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		_, err := w.Write([]byte("contents of file\n"))
+		assert.NoError(t, err)
+	}))
+	defer httpServer.Close()
+
+	chezmoitest.WithTestFS(t, map[string]any{
+		"/home/user": map[string]any{
+			".local": map[string]any{
+				"bin": map[string]any{
+					"unmanaged": "",
+				},
+				"share/chezmoi": map[string]any{
+					".chezmoiexternal.toml.tmpl": chezmoitest.JoinLines(
+						`[".local/bin/file"]`,
+						`    type = "file"`,
+						`    url = "`+httpServer.URL+`/file"`,
+					),
+					"dot_local/exact_bin/.keep": "",
+				},
+			},
+		},
+	}, func(fileSystem vfs.FS) {
+		assert.NoError(t, newTestConfig(t, fileSystem).execute([]string{"apply"}))
+		vfst.RunTests(t, fileSystem, ".local/bin",
+			vfst.TestPath("/home/user/.local/bin/file",
+				vfst.TestContentsString("contents of file\n"),
+			),
+			vfst.TestPath("/home/user/.local/bin/unmanaged",
+				vfst.TestDoesNotExist(),
+			),
+		)
+	})
+}
