@@ -1,7 +1,6 @@
 package cmd
 
 import (
-	"errors"
 	"fmt"
 	"os"
 
@@ -36,9 +35,6 @@ func (c *Config) newCDCmd() *cobra.Command {
 }
 
 func (c *Config) runCDCmd(cmd *cobra.Command, args []string) error {
-	if _, ok := os.LookupEnv("CHEZMOI_SUBSHELL"); ok {
-		return errors.New("already in a chezmoi subshell")
-	}
 	os.Setenv("CHEZMOI_SUBSHELL", "1")
 
 	cdCommand, cdArgs, err := c.cdCommand()
